<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:user="http://www.lexware.de/namespace"
	xmlns:x="http://lexware.de/taxman/9.0/messagexml.xsd">

	<xsl:import href="MsgParse.xsl"/>
	
	<xsl:output method="xml" version="1.0" encoding="UTF-16" omit-xml-declaration="no"/>
	
	<xsl:template match="/">
		<xsl:processing-instruction name="xml-stylesheet">
			<xsl:text>type="text/xsl" href="..\Gemeinsam\XSL\html_qs_alt_dlg.xsl"</xsl:text>
		</xsl:processing-instruction>

		<START>
			<DEFINITION>
				<NAME>Plausi</NAME>
				<TYPE>PLAUSI</TYPE>		
				<APPNAME>
					<xsl:value-of select="//messages/@application"/>
				</APPNAME>
			</DEFINITION>

			<DROPDOWN_LIST>
				<xsl:for-each select="/messages/rule-result[not(@severity=preceding-sibling::*/@severity)]">
					<xsl:sort select="@severity" data-type="number"/>
					<xsl:variable name="severity" select="@severity"/>
					<xsl:variable name="item-type">
						<xsl:call-template name="get-item-type">
							<xsl:with-param name="severity" select="@severity"/>
						</xsl:call-template>
					</xsl:variable>
					<DROPDOWN OPEN="JA" AKTIV="JA">
						<xsl:attribute name="TYPE"><xsl:value-of select="$item-type"/></xsl:attribute>

						<xsl:if test="$severity=1">
							<xsl:for-each select="/messages/rule-result[@severity=$severity]/message">
								<DROPDOWN_ITEMS>
									<ITEM>
										<xsl:attribute name="TYPE"><xsl:value-of select="$item-type"/></xsl:attribute>
										<LINK>
											<xsl:attribute name="ctrl-id"><xsl:value-of select=".//@ctrl-id"/></xsl:attribute> 
											<xsl:attribute name="resource-id"><xsl:value-of select=".//@resource-id"/></xsl:attribute> 
											<xsl:choose>
												<xsl:when test="count(.//@anlage-nr)&gt;0">
													<xsl:attribute name="anlage-nr"><xsl:value-of select=".//@anlage-nr"/></xsl:attribute> 
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="anlage-nr">0</xsl:attribute> 
												</xsl:otherwise>
											</xsl:choose>
											<xsl:value-of select=".//variable/@varbesch"/>
										</LINK>
									</ITEM>
								</DROPDOWN_ITEMS>
							</xsl:for-each>
						</xsl:if>
						<xsl:if test="not($severity=1)">
							<xsl:for-each select="/messages/rule-result[@severity=$severity]">
								<DROPDOWN_ITEMS>
									<ITEM>
										<xsl:attribute name="TYPE"><xsl:value-of select="$item-type"/></xsl:attribute>
										<xsl:attribute name="RULE-ID"><xsl:value-of select="@rule-id"/></xsl:attribute>
										<xsl:attribute name="HIDDEN"><xsl:value-of select="@is-hidden"/></xsl:attribute>
										<xsl:apply-templates select="*"/>
									</ITEM>
								</DROPDOWN_ITEMS>
							</xsl:for-each>
						</xsl:if>

												
					</DROPDOWN>
				</xsl:for-each>
			</DROPDOWN_LIST>
		</START>	
		
	</xsl:template>

	<xsl:template name="get-item-type">
		<xsl:param name="severity" />
		<xsl:choose>
			<xsl:when test="$severity=1">FEHLENDE_EINGABEN</xsl:when>
			<xsl:when test="$severity=2">LOGIK_CHECK</xsl:when>
			<xsl:when test="$severity=3">UNSTIMMIGKEITEN</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="text">
		<TEXT>
			<!--Msg- Head-->
			<![CDATA[<b>]]><xsl:value-of select="user:ExtractMsgHead(string(.))"/><![CDATA[</b><br/>]]>
			<!--Msg- Body-->
			<xsl:value-of select="user:ExtractMsgBody(string(.))"/>
		</TEXT>
	</xsl:template>

	<xsl:template match="variable">
		<LINK>
			<xsl:attribute name="ctrl-id"><xsl:value-of select=".//@ctrl-id"/></xsl:attribute> 
			<xsl:attribute name="resource-id"><xsl:value-of select=".//@resource-id"/></xsl:attribute> 
			<xsl:choose>
				<xsl:when test="count(.//@anlage-nr)&gt;0">
					<xsl:attribute name="anlage-nr"><xsl:value-of select=".//@anlage-nr"/></xsl:attribute> 
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="anlage-nr">0</xsl:attribute> 
				</xsl:otherwise>
			</xsl:choose>
			<xsl:value-of select="." />
		</LINK>
	</xsl:template>


	
</xsl:stylesheet>
