<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:x="http://lexware.de/taxman/9.0/messagexml.xsd"
	xmlns:msxsl="urn:schemas-microsoft-com:xslt"
	xmlns:cb="http://lexware.de/taxman/9.0/callback"
	>

	<xsl:output method="xml" version="1.0" encoding="UTF-16" omit-xml-declaration="no"/>
	
	<xsl:variable name="doc" select="/*"/>
	<xsl:variable name="themengebiet" select="msxsl:node-set($doc)/thema[@parent=0]/@title"/>
	<xsl:variable name="productname" select="msxsl:node-set($doc)/product"/>
	<xsl:variable name="tree-elems">
		<xsl:for-each select="msxsl:node-set($doc)/thema[@parent=0]">
			<xsl:variable name="cancel" select="cb:reportThema()"/>
			<xsl:if test="$cancel=0">
				<xsl:call-template name="build-count-summary">
					<xsl:with-param name="id" select="@id" />
					<xsl:with-param name="thema-path" select="@thema-path"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:for-each>
	</xsl:variable>
	
	
	<xsl:template match="/">
		<xsl:processing-instruction name="xml-stylesheet">
			<xsl:text>type="text/xsl" href="../GEMEINSAM/XSL/html_qs_alt_st.xsl"</xsl:text>
		</xsl:processing-instruction>

		<xsl:variable name="tempThemaCount" select="cb:reportThemaCount(count(msxsl:node-set($doc)/thema))"/>
<!--		<xsl:variable name="tempRuleCount" select="cb:reportRuleCount(count(//rule-result))"/>-->
		<!-- main (root) node -->		
		<DieDaten>
			<Fazit>
				<xsl:choose>	
					<xsl:when test="count(msxsl:node-set($doc)/rule-result[@severity=1 or @severity=3]) = 0">
						<xsl:attribute name="Typ">positiv</xsl:attribute>
						<caption><xsl:value-of select="$productname"/> hat Ihre Eingaben geprüft.</caption>
						<text>Glückwunsch! Bei der Prüfung wurden keine Unstimmigkeiten ermittelt.</text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="Typ">negativ</xsl:attribute>
						<caption><xsl:value-of select="$productname"/> berät Sie individuell bei Ihrer Steuererklärung.</caption>
						<text>Ihre kompletten Eingaben wurden geprüft. <![CDATA[<br/><br/>]]>Die folgenden Hinweise helfen Ihnen dabei eine korrekte Steuererklärung zu erstellen und dabei möglichst viel Steuern zu sparen.</text>
					</xsl:otherwise>
				</xsl:choose>
			</Fazit>
			
			<xsl:for-each select="msxsl:node-set($doc)/rule-result[not(@severity=preceding-sibling::*/@severity)]">
				<xsl:sort select="@severity" data-type="number"/>
				<xsl:variable name="severity" select="@severity" />
<!--				<xsl:if test="not($severity=2) or count(msxsl:node-set($doc)/rule-result[@severity=2 and @is-hidden='0']) &gt; 0">	-->
					<Header expanded="JA">
						<name>
							<xsl:call-template name="get-title">
								<xsl:with-param name="severity" select="@severity"/>
							</xsl:call-template>
						</name>
						
						<title-bmp>
							<xsl:call-template name="get-bitmap-title">
								<xsl:with-param name="severity" select="@severity"/>
							</xsl:call-template>
						</title-bmp>
						
						<knoten>
							<xsl:call-template name="get-caption">
								<xsl:with-param name="severity" select="@severity"/>
							</xsl:call-template>
							
							<items>
								<xsl:call-template name="descend-thema">
									<xsl:with-param name="parent-id" select="0"/>
									<xsl:with-param name="severity" select="$severity"/>
									<xsl:with-param name="thema-path" select="msxsl:node-set($doc)/thema[@parent=0]/@thema-path"/>
								</xsl:call-template>
							</items>	
						</knoten>
					</Header>
<!--				</xsl:if>		-->
				
			</xsl:for-each>
			
<!--			<xsl:copy-of select="msxsl:node-set($tree-elems)"/>	-->
		</DieDaten>
	
	</xsl:template>


	<xsl:template name="get-title">
		<xsl:param name="severity" />
		<xsl:choose>
			<xsl:when test="$severity=1">Zu ergänzende Angaben</xsl:when>
			<xsl:when test="$severity=2">Plausibilitäts- und Verständnisprüfung</xsl:when>
			<xsl:when test="$severity=3">Zu überarbeitende Angaben</xsl:when>
			<xsl:when test="$severity=4">Tipps und Hinweise zur Steuererklärung</xsl:when>
			<xsl:when test="$severity=5">Steuerstrategie</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="get-bitmap-title">
		<xsl:param name="severity" />
		<xsl:choose>
			<xsl:when test="$severity=1">../gemeinsam/images/Steuerpruefer/FehlendeEingaben.bmp</xsl:when>
			<xsl:when test="$severity=2">../gemeinsam/images/Steuerpruefer/LogikCheck.bmp</xsl:when>
			<xsl:when test="$severity=3">../gemeinsam/images/Steuerpruefer/Umstimmigkeiten.bmp</xsl:when>
			<xsl:when test="$severity=4">../gemeinsam/images/Steuerpruefer/Tipps.bmp</xsl:when>
			<xsl:when test="$severity=5">../gemeinsam/images/Steuerpruefer/Steuerstratege.bmp</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="get-caption">
		<xsl:param name="severity" />
		<xsl:choose>
			<xsl:when test="$severity=1">
				<caption>
					<xsl:value-of select="$productname"/> hat festgestellt, dass für Ihre Steuererklärung relevante Eingaben nicht gemacht wurden.
					<![CDATA[<br/>Damit alle benötigten Daten vorhanden sind , sollten Sie die nachfolgenden Angaben vervollständigen.]]>
				</caption>
				<image>../Gemeinsam/Images/Steuerpruefer/hiearchie_fehlAngaben.bmp</image>
			</xsl:when>
			<xsl:when test="$severity=2">
				<caption>
					Bei der Überprüfung sind <xsl:value-of select="$productname"/> inhaltliche Zusammenhänge aufgefallen, die sich in ihrer Folgerichtigkeit ausschließen oder widersprechen.		
				</caption>
				<image>../Gemeinsam/Images/Steuerpruefer/hiearchie_LogikCheck.bmp</image>
			</xsl:when>
			<xsl:when test="$severity=3">
				<caption>
					<xsl:value-of select="$productname"/> hat bei der Auswertung Ihrer Daten folgende Unstimmigkeiten ermittelt.
					<![CDATA[<br/>Bitte überprüfen Sie die Angaben.]]>
				</caption>
				<image>../Gemeinsam/Images/Steuerpruefer/hiearchie_Unstimmigkeit.bmp</image>
			</xsl:when>
			<xsl:when test="$severity=4">
				<caption>
					Damit Sie alle Möglichkeiten zum Steuern sparen ausschöpfen, hat <xsl:value-of select="$productname"/> praxisnahe Tipps und Hinweise für Sie zusammengestellt. 
				</caption>
				<image>../Gemeinsam/Images/Steuerpruefer/hiearchie_Tipps.bmp</image>
			</xsl:when>
			<xsl:when test="$severity=5">
				<caption>
					Nutzen Sie die Tipps von <xsl:value-of select="$productname"/>  für Ihre persönliche Steuerstrategie, damit Sie auch weiterhin kräftig Steuern sparen.
				</caption>
				<image>../Gemeinsam/Images/Steuerpruefer/hiearchie_Tipps.bmp</image>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="build-count-summary">
		<xsl:param name="id"/>
		<xsl:param name="thema-path"/>
		
		<xsl:variable name="count-fields">
			<xsl:for-each select="msxsl:node-set($doc)/rule-result[thema/@id=$id and thema/@thema-path=$thema-path and not(@severiy = preceding-sibling::*[thema/@id=$id and thema/@thema-path=$thema-path]/@severity)]">
				<xsl:variable name="severity" select="@severity"/>
				<count>
					<xsl:attribute name="severity">
						<xsl:value-of select="$severity"/>
					</xsl:attribute>
					<xsl:value-of select="count(msxsl:node-set($doc)/rule-result[@severity=$severity and thema/@id=$id and thema/@thema-path=$thema-path])"/>
				</count>
			</xsl:for-each>
				
			<xsl:for-each select="msxsl:node-set($doc)/thema[@parent=$id and starts-with(@thema-path,$thema-path)]">
				<xsl:variable name="cancel" select="cb:reportThema()"/>
				<xsl:if test="$cancel=0">
					<xsl:call-template name="build-count-summary">
						<xsl:with-param name="id" select="@id"/>
						<xsl:with-param name="thema-path" select="@thema-path"/>
					</xsl:call-template>		
				</xsl:if>
			</xsl:for-each>
		</xsl:variable>
		
		<xsl:for-each select="msxsl:node-set($count-fields)/count[not (@severity=preceding-sibling::*/@severity)]">
			<xsl:variable name="severity" select="@severity"/>
			<count>
				<xsl:attribute name="severity">
					<xsl:value-of select="$severity"/>
				</xsl:attribute>
				<xsl:value-of select="sum(msxsl:node-set($count-fields)/count[@severity=$severity])"/>
			</count>

			<xsl:if test="sum(msxsl:node-set($count-fields)/count[@severity=$severity])&gt;0">
				<elem>
					<xsl:attribute name="id">	<xsl:value-of select="$id"/></xsl:attribute>
					<xsl:attribute name="severity"><xsl:value-of select="$severity"/></xsl:attribute>
					<xsl:attribute name="thema-path"><xsl:value-of select="$thema-path"/></xsl:attribute>
					<xsl:value-of select="sum(msxsl:node-set($count-fields)/count[@severity=$severity])"/>
				</elem>
			</xsl:if>
		</xsl:for-each>
		<xsl:copy-of select="msxsl:node-set($count-fields)/elem"/>
	</xsl:template>

	<xsl:template name="descend-thema">
		<xsl:param name="parent-id"/>
		<xsl:param name="severity" />
		<xsl:param name="thema-path"/>

		<xsl:for-each select="msxsl:node-set($doc)/thema[@parent=$parent-id and starts-with(@thema-path,$thema-path) ]">
			<xsl:variable name="thema-id" select="@id"/>
			<xsl:variable name="this-thema-path" select="@thema-path"/>
			
			
<!--
			<xsl:variable name="count-summary-debug">
				<xsl:call-template name="build-count-summary">
					<xsl:with-param name="id" select="@id" />
					<xsl:with-param name="severity" select="$severity" />
					<xsl:with-param name="thema-path" select="@thema-path"/>
				</xsl:call-template>
			</xsl:variable>
			
			<SUM>
				<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
				<xsl:attribute name="severity"><xsl:value-of select="$severity"/></xsl:attribute>
				<xsl:attribute name="thema-path"><xsl:value-of select="@thema-path"/></xsl:attribute>
				<xsl:copy-of select="msxsl:node-set($count-summary-debug)"/>
			</SUM>
-->
<!--
			<xsl:variable name="count-summary">
				<xsl:call-template name="build-count-summary">
					<xsl:with-param name="id" select="@id" />
					<xsl:with-param name="severity" select="$severity" />
					<xsl:with-param name="thema-path" select="@thema-path"/>
				</xsl:call-template>
			</xsl:variable>
-->
			<xsl:variable name="count-summary">
				<count>
					<xsl:choose>
						<xsl:when test="msxsl:node-set($tree-elems)/elem[@id=$thema-id and @severity=$severity and @thema-path=$this-thema-path] &gt; 0">
							<xsl:value-of select="msxsl:node-set($tree-elems)/elem[@id=$thema-id and @severity=$severity and @thema-path=$this-thema-path]"/>
						</xsl:when>
						<xsl:otherwise>0</xsl:otherwise>
					</xsl:choose>
				</count>
			</xsl:variable>
			<xsl:if test="msxsl:node-set($count-summary)/count&gt;0">
				<xsl:choose>
					<xsl:when test="not(@title='')">
						<item type="caption">
							<caption><xsl:value-of select="@title" disable-output-escaping="yes"/></caption>
							<xsl:call-template name="write-thema-rules">
								<xsl:with-param name="parent-id" select="$parent-id"/>
								<xsl:with-param name="severity" select="$severity"/>
								<xsl:with-param name="thema-path" select="$this-thema-path"/>
								<xsl:with-param name="thema-id" select="$thema-id"/>
							</xsl:call-template>
						</item>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="write-thema-rules">
							<xsl:with-param name="parent-id" select="$parent-id"/>
							<xsl:with-param name="severity" select="$severity"/>
							<xsl:with-param name="thema-path" select="$this-thema-path"/>
							<xsl:with-param name="thema-id" select="$thema-id"/>
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
		</xsl:for-each>
			
	</xsl:template>
	
	<xsl:template name="write-thema-rules">
		<xsl:param name="parent-id"/>
		<xsl:param name="severity" />
		<xsl:param name="thema-path"/>
		<xsl:param name="thema-id"/>

		<xsl:for-each select="msxsl:node-set($doc)/thema[@id=$thema-id and starts-with(@thema-path,$thema-path) and not(@modul = preceding-sibling::*[@id=$thema-id and starts-with(@thema-path,$thema-path)]/@modul)]">
			<xsl:sort select="@modul" data-type="number"/>
			<xsl:choose>
				<xsl:when test="@modul=-1 or @n-fach-title=''">
					<!-- processing the 1-fach modul -->	
					<xsl:for-each select="msxsl:node-set($doc)/rule-result[thema/@id=$thema-id and @severity=$severity and thema/@thema-path=$thema-path]">
						<xsl:call-template name="write-rule-result">
							<xsl:with-param name="rule-result" select="."/>
							<xsl:with-param name="severity" select="$severity"/>
						</xsl:call-template>
					</xsl:for-each>
				
					<xsl:call-template name="descend-thema">
						<xsl:with-param name="parent-id" select="@id" />
						<xsl:with-param name="severity" select="$severity" />
						<xsl:with-param name="thema-path" select="@thema-path"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<!-- processing the n-fach modul -->
					<xsl:variable name="modul" select="@modul"/>
					<xsl:for-each select="msxsl:node-set($doc)/thema[@id=$thema-id and starts-with(@thema-path,$thema-path) and @modul=$modul]">
						<xsl:variable name="themapath-current" select="@thema-path"/>
						<item type="caption" style="nfach">
							<caption><xsl:value-of select="@n-fach-title" disable-output-escaping="yes"/></caption>
							<xsl:for-each select="msxsl:node-set($doc)/rule-result[thema/@id=$thema-id and @severity=$severity and thema/@thema-path=$themapath-current]">
								<xsl:call-template name="write-rule-result">
									<xsl:with-param name="rule-result" select="."/>
									<xsl:with-param name="severity" select="$severity"/>
								</xsl:call-template>
							</xsl:for-each>

							<xsl:call-template name="descend-thema">
								<xsl:with-param name="parent-id" select="@id" />
								<xsl:with-param name="severity" select="$severity" />
								<xsl:with-param name="thema-path" select="$themapath-current"/>
							</xsl:call-template>
						
						</item>
					</xsl:for-each>
				</xsl:otherwise>
			</xsl:choose>	
		
		</xsl:for-each>

	</xsl:template>

	
	<xsl:template name="write-rule-result">
		<xsl:param name="rule-result" />
		<xsl:param name="severity" />
		
		<xsl:choose>
			<xsl:when test="$severity=1">
				<xsl:for-each select="msxsl:node-set($rule-result)/message/variable">
					<item type="link">
						<link>
							<xsl:attribute name="ctrl-id"><xsl:value-of select=".//@ctrl-id"/></xsl:attribute> 
							<xsl:attribute name="resource-id"><xsl:value-of select=".//@resource-id"/></xsl:attribute> 
							<xsl:choose>
								<xsl:when test="count(@anlage-nr)&gt;0">
									<xsl:attribute name="anlage-nr"><xsl:value-of select="@anlage-nr"/></xsl:attribute> 
								</xsl:when>
								<xsl:otherwise>
									<xsl:attribute name="anlage-nr">0</xsl:attribute> 
								</xsl:otherwise>
							</xsl:choose>
							<xsl:value-of select="@varbesch"/>
						</link>
					</item>
				</xsl:for-each>
			</xsl:when>

			<xsl:when test="$severity=2">
				<!--xsl:if test="not(@is-hidden=1)"-->
					<item type="text">
						<xsl:for-each select="msxsl:node-set($rule-result)/message/*">
							<xsl:apply-templates select="."/>
						</xsl:for-each>
						<item type="check">
							<xsl:attribute name="rule-id">
								<xsl:value-of select="msxsl:node-set($rule-result)/@rule-id"/>
							</xsl:attribute>
							<xsl:attribute name="is-hidden">
								<xsl:value-of select="msxsl:node-set($rule-result)/@is-hidden"/>
							</xsl:attribute>
						</item>
					</item>
				<!--/xsl:if-->
			</xsl:when>

			<xsl:otherwise>
				<item type="text">
					<xsl:for-each select="msxsl:node-set($rule-result)/message/*">
						<xsl:apply-templates select="."/>
					</xsl:for-each>
				</item>
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:template>
	
	<xsl:template match="text">
		<text><xsl:value-of select="."/></text>
	</xsl:template>

	<xsl:template match="variable">
		<link>
			<xsl:attribute name="ctrl-id"><xsl:value-of select=".//@ctrl-id"/></xsl:attribute> 
			<xsl:attribute name="resource-id"><xsl:value-of select=".//@resource-id"/></xsl:attribute> 
			<xsl:choose>
				<xsl:when test="count(@anlage-nr)&gt;0">
					<xsl:attribute name="anlage-nr"><xsl:value-of select="@anlage-nr"/></xsl:attribute> 
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="anlage-nr">0</xsl:attribute> 
				</xsl:otherwise>
			</xsl:choose>
			<xsl:value-of select="."/>
		</link>
	</xsl:template>
	
	

</xsl:stylesheet>

  